@@ -1,14 +1,13 @@
 """Algorithms for generating synthetic data"""
 
 from synthesis.synthesizers.marginal import MarginalSynthesizer, UniformSynthesizer
-from synthesis.synthesizers.contingency import ContingencySynthesizer, ContingencySynthesizerFix
+from synthesis.synthesizers.contingency import ContingencySynthesizer
 from synthesis.synthesizers.privbayes import PrivBayes, PrivBayesFix
 
 __all__ = [
     'MarginalSynthesizer',
     'UniformSynthesizer',
     'ContingencySynthesizer',
-    'ContingencySynthesizerFix',
     'PrivBayes',
     'PrivBayesFix'
 ]
\ No newline at end of file
