@@ -13,7 +13,7 @@ from sklearn.metrics import mutual_info_score
 from collections import namedtuple
 
 import synthesis.synthesizers.utils as utils
-from synthesis.synthesizers._base import BaseDPSynthesizer, FixedSamplingMixin
+from synthesis.synthesizers._base import BaseDPSynthesizer
 from thomas.core import BayesianNetwork
 from diffprivlib.mechanisms import Exponential
 
@@ -159,7 +159,7 @@ class PrivBayes(BaseDPSynthesizer):
             # print("Pre-defined network init: {}".format(self.network_))
             for i, pair in enumerate(self.network_init):
                 if self.verbose:
-                    print("{}/{} - init node {} - with parents: {}".format(i + 1, len(self.network_init),
+                    print("{}/{} - init node {} - with parents: {}".format(i + 1, len(nodes),
                                                                            pair.node, pair.parents))
             self.network_ = self.network_init.copy()
             return nodes, nodes_selected
@@ -311,7 +311,7 @@ class PrivBayes(BaseDPSynthesizer):
         return l1_distance
 
 
-class PrivBayesFix(FixedSamplingMixin, PrivBayes):
+class PrivBayesFix(PrivBayes):
     """Extension to PrivBayes class to allow user to fix pre-sampled columns. Can be used to generate additional items
     for an already released synthetic dataset.
     """
@@ -336,7 +336,6 @@ class PrivBayesFix(FixedSamplingMixin, PrivBayes):
             print("\nRemaining synthetic columns generated")
         return data_synth
 
-
     def _generate_data(self, fixed_data):
         n_records = fixed_data.shape[0]
         data_synth = np.empty([n_records, len(self.columns_)], dtype=object)
@@ -375,6 +374,25 @@ class PrivBayesFix(FixedSamplingMixin, PrivBayes):
             record[node.name] = sampled_node_value
         return record
 
+    def _check_fixed_data(self, data):
+        """Checks whether the columns in fixed data where also seen in fit"""
+        if isinstance(data, pd.Series):
+            data = data.to_frame()
+
+        if not np.all([c in self.columns_ for c in data.columns]):
+            raise ValueError('Columns in fixed data not seen in fit.')
+        if set(data.columns) == set(self.columns_):
+            raise ValueError('Fixed data already contains all the columns that were seen in fit.')
+
+        if self.verbose:
+            sample_columns = [c for c in self.columns_ if c not in data.columns]
+            print('Columns sampled and added to fixed data: {}'.format(sample_columns))
+        # prevent integer column indexing issues
+        data.columns = data.columns.astype(str)
+        # make all columns categorical.
+        data = data.astype(str)
+        return data
+
 if __name__ == "__main__":
     data_path = '../../examples/data/original/adult.csv'
     data = pd.read_csv(data_path, engine='python')
@@ -408,7 +426,6 @@ if __name__ == "__main__":
     pbfix.set_network(init_network)
     pbfix.fit(data)
     df_synth_remaining = pbfix.sample_remaining_columns(df_synth[['age', 'education']])
-    df_synth_remaining = pbfix.sample_remaining_columns(df_synth['age'])
 
 
     """test scoring functions"""
